@@ -8,13 +8,16 @@ use Doctrine\DBAL\Driver;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\DB2111Platform;
 use Doctrine\DBAL\Platforms\DB2Platform;
+use Doctrine\DBAL\Platforms\MariaDb1010Platform;
 use Doctrine\DBAL\Platforms\MariaDb1027Platform;
 use Doctrine\DBAL\Platforms\MariaDb1052Platform;
 use Doctrine\DBAL\Platforms\MariaDb1060Platform;
 use Doctrine\DBAL\Platforms\MySQL57Platform;
 use Doctrine\DBAL\Platforms\MySQL80Platform;
+use Doctrine\DBAL\Platforms\MySQL84Platform;
 use Doctrine\DBAL\Platforms\MySQLPlatform;
 use Doctrine\DBAL\Platforms\PostgreSQL100Platform;
+use Doctrine\DBAL\Platforms\PostgreSQL120Platform;
 use Doctrine\DBAL\Platforms\PostgreSQL94Platform;
 use Doctrine\DBAL\VersionAwarePlatformDriver;
 use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
@@ -51,8 +54,8 @@ class VersionAwarePlatformDriverTest extends TestCase
             ['8', MySQL80Platform::class],
             ['8.0', MySQL80Platform::class],
             ['8.0.11', MySQL80Platform::class],
-            ['8.4.1', MySQL80Platform::class],
-            ['9.0.0', MySQL80Platform::class],
+            ['8.4.1', MySQL84Platform::class],
+            ['9.0.0', MySQL84Platform::class],
             ['6', MySQL57Platform::class],
             ['10.0.15-MariaDB-1~wheezy', MySQLPlatform::class],
             ['5.5.5-10.1.25-MariaDB', MySQLPlatform::class],
@@ -64,7 +67,7 @@ class VersionAwarePlatformDriverTest extends TestCase
             ['10.5.2-MariaDB-1~lenny-log', MariaDB1052Platform::class],
             ['mariadb-10.6.0', MariaDb1060Platform::class],
             ['mariadb-10.9.3', MariaDb1060Platform::class],
-            ['11.0.2-MariaDB-1:11.0.2+maria~ubu2204', MariaDb1060Platform::class],
+            ['11.0.2-MariaDB-1:11.0.2+maria~ubu2204', MariaDb1010Platform::class],
         ];
     }
 
@@ -88,6 +91,7 @@ class VersionAwarePlatformDriverTest extends TestCase
             ['9.4.0', PostgreSQL94Platform::class],
             ['9.4.1', PostgreSQL94Platform::class],
             ['10', PostgreSQL100Platform::class],
+            ['12', PostgreSQL120Platform::class],
         ];
     }
 
