@@ -5,6 +5,7 @@ namespace Doctrine\DBAL\Tests\Functional\Schema;
 use Doctrine\DBAL\Driver\ServerInfoAwareConnection;
 use Doctrine\DBAL\Exception\DatabaseObjectNotFoundException;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
+use Doctrine\DBAL\Platforms\PostgreSQL120Platform;
 use Doctrine\DBAL\Platforms\PostgreSQLPlatform;
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
 use Doctrine\DBAL\Schema\Comparator;
@@ -334,6 +335,35 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertFalse($diff);
     }
 
+    /**
+     * @param callable(AbstractSchemaManager):Comparator $comparatorFactory
+     *
+     * @dataProvider \Doctrine\DBAL\Tests\Functional\Schema\ComparatorTestUtils::comparatorProvider
+     */
+    public function testGeneratedColumn(callable $comparatorFactory): void
+    {
+        $wrappedConnection = $this->connection->getWrappedConnection();
+        if (! $this->connection->getDatabasePlatform() instanceof PostgreSQL120Platform) {
+             self::markTestSkipped('Generated columns are not supported in Postgres 11 and earlier');
+        }
+
+        $table = new Table('ddc6198_generated_always_as');
+        $table->addColumn('id', Types::INTEGER);
+        $table->addColumn(
+            'idIsOdd',
+            Types::BOOLEAN,
+            ['columnDefinition' => 'boolean GENERATED ALWAYS AS (id % 2 = 1) STORED', 'notNull' => false],
+        );
+
+        $this->dropAndCreateTable($table);
+
+        $databaseTable = $this->schemaManager->introspectTable($table->getName());
+
+        $diff = $comparatorFactory($this->schemaManager)->diffTable($table, $databaseTable);
+
+        self::assertFalse($diff);
+    }
+
     /**
      * PostgreSQL stores BINARY columns as BLOB
      */
