@@ -123,10 +123,20 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
             'NVARCHAR(50)',
             $this->platform->getStringTypeDeclarationSQL(['length' => 50]),
         );
+        self::assertEquals(
+            'NVARCHAR(50)',
+            $this->platform->getStringTypeDeclarationSQL(
+                ['length' => 50, 'fixed' => false],
+            ),
+        );
         self::assertEquals(
             'NVARCHAR(255)',
             $this->platform->getStringTypeDeclarationSQL([]),
         );
+        self::assertEquals(
+            'NVARCHAR(255)',
+            $this->platform->getStringTypeDeclarationSQL(['fixed' => false]),
+        );
         self::assertSame('VARCHAR(MAX)', $this->platform->getClobTypeDeclarationSQL([]));
         self::assertSame(
             'VARCHAR(MAX)',
@@ -134,6 +144,34 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
         );
     }
 
+    public function testGeneratesTypeDeclarationsForAsciiStrings(): void
+    {
+        self::assertEquals(
+            'CHAR(10)',
+            $this->platform->getAsciiStringTypeDeclarationSQL(
+                ['length' => 10, 'fixed' => true],
+            ),
+        );
+        self::assertEquals(
+            'VARCHAR(50)',
+            $this->platform->getAsciiStringTypeDeclarationSQL(['length' => 50]),
+        );
+        self::assertEquals(
+            'VARCHAR(50)',
+            $this->platform->getAsciiStringTypeDeclarationSQL(
+                ['length' => 50, 'fixed' => false],
+            ),
+        );
+        self::assertEquals(
+            'VARCHAR(255)',
+            $this->platform->getAsciiStringTypeDeclarationSQL([]),
+        );
+        self::assertEquals(
+            'VARCHAR(255)',
+            $this->platform->getAsciiStringTypeDeclarationSQL(['fixed' => false]),
+        );
+    }
+
     public function testPrefersIdentityColumns(): void
     {
         self::assertTrue($this->platform->prefersIdentityColumns());
@@ -1145,6 +1183,12 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
 
         self::assertTrue($this->platform->hasDoctrineTypeMappingFor('uniqueidentifier'));
         self::assertSame(Types::GUID, $this->platform->getDoctrineTypeMapping('uniqueidentifier'));
+
+        self::assertTrue($this->platform->hasDoctrineTypeMappingFor('sysname'));
+        self::assertSame(Types::STRING, $this->platform->getDoctrineTypeMapping('sysname'));
+
+        self::assertTrue($this->platform->hasDoctrineTypeMappingFor('xml'));
+        self::assertSame(Types::TEXT, $this->platform->getDoctrineTypeMapping('xml'));
     }
 
     protected function getBinaryMaxLength(): int
